;; This "home-environment" file can be passed to 'guix home reconfigure'
;; to reproduce the content of your profile.  This is "symbolic": it only
;; specifies package names.  To reproduce the exact same profile, you also
;; need to capture the channels being used, as returned by "guix describe".
;; See the "Replicating Guix" section in the manual.

(use-modules (gnu home)
             (gnu packages)
             (gnu packages vim)
             (gnu packages gcc)
             (gnu packages gnupg)
             (gnu services)
             (guix packages)
             (guix gexp)
             (gnu home services shells)
             (gnu home services desktop)
             (gnu home services gnupg)
             (gnu home services)
             (ryan-services pipewire))

(define my-neovim
  (package
    (inherit neovim)
    (native-inputs
      (modify-inputs (package-native-inputs neovim)
                     (prepend gcc-12)))))

(home-environment
  ;; Below is the list of packages that will show up in your
  ;; Home profile, under ~/.guix-home/profile.
  (packages (append (specifications->packages (list "bat"
                                                    "xdg-utils"
                                                    "abook"
                                                    "libnotify"
                                                    "fzf"
                                                    "qrencode"
                                                    "binutils"
                                                    "gcc-toolchain"
                                                    "borg"
                                                    "restic"
                                                    "rsync"
                                                    "pv"
                                                    "python-msgpack"
                                                    "libreoffice"
                                                    "flatpak"
                                                    "gnupg"
                                                    "lsof"
                                                    "pavucontrol"
                                                    "bind:utils"
                                                    "font-cns11643"
                                                    "syncthing"
                                                    "imv"
                                                    "perl"
                                                    "tor"
                                                    "unzip"
                                                    "alacritty"
                                                    "htop"
                                                    "curl"
                                                    "pandoc"
                                                    "texlive-bin"
                                                    "texlive-scheme-basic"
                                                    "texlive-txfonts"
                                                    "texlive-amsfonts"
                                                    "texlive-lm"
                                                    "texlive-lm-math"
                                                    "texlive-iftex"
                                                    "texlive-unicode-math"
                                                    "texlive-fontspec"
                                                    "texlive-xcolor"
                                                    "texlive-geometry"
                                                    "texlive-hyperref"
                                                    "texlive-parskip"
                                                    "texlive-etoolbox"
                                                    "zathura"
                                                    "zathura-pdf-mupdf"
                                                    "fzf"
                                                    "weechat"
                                                    "gimp"
                                                    "python"
                                                    "python:tk"
                                                    "file"
                                                    "python-lsp-server"
                                                    "kdenlive"
                                                    "sqlite"
                                                    "mpv"
                                                    "playerctl"
                                                    "aerc"
                                                    "tcpdump"
                                                    "pamixer"
                                                    "git"
                                                    "node"
                                                    "git-lfs"))
                    (list my-neovim)))

  ;; Below is the list of Home services.  To search for available
  ;; services, run 'guix home search KEYWORD' in a terminal.
  (services
   (list (service home-bash-service-type
                  (home-bash-configuration
                   (aliases '(("grep" . "grep --color=auto") ("ll" . "ls -l")
                              ("ls" . "ls -p --color=auto")
                              ("python" . "python3")))
                   (bashrc (list (local-file
                                  "bashrc")))
                   (bash-profile (list (local-file
                                        "bash_profile")))))
         (service home-xdg-configuration-files-service-type
                  `(("nvim/init.vim" ,(local-file "nvim/config/init.vim"))
                    ("nvim/after/ftplugin/markdown/custom.vim" ,(local-file "nvim/config/after/ftplugin/markdown/custom.vim"))
                    ("sway" ,(local-file "sway" #:recursive? #t))
                    ("hypr" ,(local-file "hypr" #:recursive? #t))
                    ("waybar" ,(local-file "waybar" #:recursive? #t))
                    ("alacritty" ,(local-file "alacritty" #:recursive? #t))
                    ("aerc" ,(local-file "aerc" #:recursive? #t))
                    ("home-manager" ,(local-file "nix-home-manager" #:recursive? #t)) ))
         (service home-files-service-type
                  `((".local/share/nvim/site/autoload/plug.vim" ,(local-file "nvim/plugin-manager/plug.vim"))
                    (".ssh/config" ,(local-file "ssh/config"))
                    ;(".gnupg/sshcontrol" ,(local-file "gnupg/sshcontrol"))
                    ;(".gnupg/gpg-agent.conf" ,(local-file "gnupg/gpg-agent.conf"))
                    (".fonts" ,(local-file "fonts" #:recursive? #t))
                    (".nix-channels" ,(local-file "nix-channels"))))
         (service home-pipewire-service-type)
         (service home-dbus-service-type)
         (service home-gpg-agent-service-type
                  (home-gpg-agent-configuration
                    (pinentry-program
                      (file-append pinentry "/bin/pinentry"))
                    (ssh-support? #t))) )))
